@@ -159,6 +159,9 @@ class CircleAccessRequest(Model):
         authenticated_perms = ['add']
         owner_perms = ['add']
         rdf_type = 'hd:circleaccessrequest'
+    
+    def __str__(self):
+        return '{} requests access to {}'.format(self.user.urlid, self.circle.urlid)
 
 
 @receiver(post_save, sender=CircleMember)
@@ -262,7 +265,7 @@ if 'djangoldp_notification' in settings.DJANGOLDP_PACKAGES:
                 })
 
                 send_mail(
-                    _("Someone requested access to your circle"),
+                    _("Someone requested access to your space"),
                     to_text(html_message),
                     email_from,
                     [instance.user.email],
@@ -282,7 +285,8 @@ if 'djangoldp_notification' in settings.DJANGOLDP_PACKAGES:
                     }
                 )
 
-                email_title = (ar.status == "Accepted") if _("Your access request has been accepted") else  _("Your access request has been refused")
+                email_title = _("Your access request has been accepted on the space") if (ar.status == "Accepted") else  _("Your access request has been refused on the space")
+                email_title = email_title + (ar.circle.name if ar.circle.name is not None else ar.circle.urlid)
                 send_mail(
                     email_title,
                     to_text(html_message),
@@ -308,9 +312,10 @@ if 'djangoldp_notification' in settings.DJANGOLDP_PACKAGES:
         notification_type = "CircleAccessRequest"
         author = instance.user if created else instance.responded_to_by
         author = author.urlid if author is not None else str(_("Auteur inconnu"))
-        summary = (instance.status == "Accepted") if _("Your access request has been accepted") else  _("Your access request has been refused")
+        summary = _("Your access request has been accepted on the space") if (instance.status == "Accepted") else  _("Your access request has been refused on the space")
+        summary = summary + (instance.circle.name if instance.circle.name is not None else instance.circle.urlid)
         if created:
-            summary = _('New Circle access request')
+            summary = _('New Space access request')
             
         notification = {
             "@context": settings.LDP_RDF_CONTEXT,
