@@ -511,3 +511,15 @@ class PermissionsTestCase(APITestCase):
         response = self.client.patch('/circleaccessrequests/{}/'.format(ar.pk),
                                      data=json.dumps(payload), content_type='application/ld+json')
         self.assertEqual(response.status_code, 404)
+    
+    def test_access_request_removed_when_user_removed(self):
+        self.setUpLoggedInUser()
+        self.setUpCircle('Restrict', self.user)
+
+        other_user = get_random_user()
+        ar = CircleAccessRequest.objects.create(circle=self.circle, user=other_user, status='Accepted')
+        cm = CircleMember.objects.get(circle=self.circle, user=other_user)
+
+        cm.delete()
+        ar = CircleAccessRequest.objects.filter(pk=ar.pk)
+        self.assertFalse(ar.exists())
